summaryrefslogtreecommitdiff
path: root/ipacm/src/IPACM_IfaceManager.cpp
diff options
context:
space:
mode:
authorSkylar Chang <chiaweic@codeaurora.org>2014-03-28 16:31:42 -0700
committerSkylar Chang <chiaweic@codeaurora.org>2014-05-28 16:40:28 -0700
commit18a55e05716c3cce4ef0deecf6267b1f8e949ae9 (patch)
treef58d53f682026018fe39abb8077794c19e24f017 /ipacm/src/IPACM_IfaceManager.cpp
parent11240567c31e1788914d790a9197d61cc048fe34 (diff)
downloadipacfg-mgr-18a55e05716c3cce4ef0deecf6267b1f8e949ae9.tar.gz
IPACM: support 8994 private subnet change
In android platform, when doing wlan or rndis thethering, the subnet is different than LE, IPACM should dynamically change private subnet by listening for new_addr netlink event for those LAN interface Change-Id: I36a8fbe0055098b965209326519d0c5d0cefbe0d
Diffstat (limited to 'ipacm/src/IPACM_IfaceManager.cpp')
-rw-r--r--ipacm/src/IPACM_IfaceManager.cpp4
1 files changed, 3 insertions, 1 deletions
diff --git a/ipacm/src/IPACM_IfaceManager.cpp b/ipacm/src/IPACM_IfaceManager.cpp
index 9c258a8..e0e115b 100644
--- a/ipacm/src/IPACM_IfaceManager.cpp
+++ b/ipacm/src/IPACM_IfaceManager.cpp
@@ -163,7 +163,8 @@ int IPACM_IfaceManager::create_iface_instance(int if_index, ipacm_wan_iface_type
IPACM_EvtDispatcher::registr(IPA_HANDLE_WAN_DOWN_V6, lan);
IPACM_EvtDispatcher::registr(IPA_LINK_DOWN_EVENT, lan);
IPACM_EvtDispatcher::registr(IPA_LAN_DELETE_SELF, lan);
- IPACM_EvtDispatcher::registr(IPA_CFG_CHANGE_EVENT, lan); // register for IPA_CFG_CHANGE event
+ IPACM_EvtDispatcher::registr(IPA_CFG_CHANGE_EVENT, lan); // register for IPA_CFG_CHANGE event
+ IPACM_EvtDispatcher::registr(IPA_PRIVATE_SUBNET_CHANGE_EVENT, lan); // register for IPA_PRIVATE_SUBNET_CHANGE_EVENT event
IPACMDBG("ipa_LAN (%s):ipa_index (%d) instance open/registr ok\n", lan->dev_name, lan->ipa_if_num);
registr(ipa_interface_index, lan);
/* solve the new_addr comes earlier issue */
@@ -207,6 +208,7 @@ int IPACM_IfaceManager::create_iface_instance(int if_index, ipacm_wan_iface_type
IPACM_EvtDispatcher::registr(IPA_HANDLE_WAN_DOWN_V6, wl);
IPACM_EvtDispatcher::registr(IPA_WLAN_LINK_DOWN_EVENT, wl);
IPACM_EvtDispatcher::registr(IPA_LAN_DELETE_SELF, wl);
+ IPACM_EvtDispatcher::registr(IPA_PRIVATE_SUBNET_CHANGE_EVENT, wl); // register for IPA_PRIVATE_SUBNET_CHANGE_EVENT event
IPACMDBG("ipa_WLAN (%s):ipa_index (%d) instance open/registr ok\n", wl->dev_name, wl->ipa_if_num);
registr(ipa_interface_index, wl);
/* solve the new_addr comes earlier issue */